@@ -1,14 +1,13 @@
 package Data::Xslate;
-
-$Data::Xslate::VERSION = '0.05';
+use 5.008001;
+use strict;
+use warnings;
+our $VERSION = '0.06';
 
 use Text::Xslate;
 use Carp qw( croak );
 use Storable qw( freeze thaw );
 
-use strict;
-use warnings;
-
 # A tied-hash class used to expose the data as the Xslate
 # vars when processing the data.
 {
@@ -507,9 +506,9 @@ Data-Xslate GitHub issue tracker:
 
 L<https://github.com/bluefeet/Data-Xslate/issues>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Aran Deltac <bluefeetE<64>gmail.com>
+    Aran Clary Deltac <bluefeet@gmail.com>
 
 =head1 ACKNOWLEDGEMENTS
 
